/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui.components;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Observable;
import java.util.Observer;

import javax.swing.JComboBox;

import net.sf.genomeview.data.Model;
import net.sf.jannot.AminoAcidMapping;

public class AAMappingChooser extends JComboBox implements ActionListener,
		Observer {

	
	private static final long serialVersionUID = 8572963039431236614L;
	private Model model;

	public AAMappingChooser(Model model) {
		this.model = model;
		model.addObserver(this);
		setEditable(false);
		for (AminoAcidMapping aamap : AminoAcidMapping.values())
			this.addItem(aamap);
		this.addActionListener(this);
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		if (!model.getAAMapping().equals(this.getSelectedItem()))
			model.setAAMapping(model.vlm.getSelectedEntry(),
					(AminoAcidMapping) this.getSelectedItem());
	}

	@Override
	public void update(Observable arg0, Object arg1) {
		this.removeActionListener(this);
		this.setSelectedItem(model.getAAMapping());
		this.addActionListener(this);

	}

}
