/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2013 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui.menu.navigation;

import java.awt.event.ActionEvent;
import java.util.Observable;

import javax.swing.ImageIcon;

import net.sf.genomeview.data.Model;
import net.sf.genomeview.gui.menu.AbstractModelAction;
import net.sf.jannot.Location;

/**
 * Moves the view of the annotation view to the right.
 * 
 * @author Thomas Abeel
 * 
 */
public class AnnotationMoveRightAction extends AbstractModelAction {

    @Override
    public void update(Observable o, Object obj) {
        setEnabled(model.vlm.getAnnotationLocationVisible().end() < model.vlm.getSelectedEntry().getMaximumLength());
    }

    /**
     * 
     */
    private static final long serialVersionUID = 8307496875031190561L;

    public AnnotationMoveRightAction(Model model) {
        super(null, new ImageIcon(model.getClass().getResource("/images/arrow_right.png")), model);

    }

    @Override
    public void actionPerformed(ActionEvent arg0) {
        Location r = model.vlm.getAnnotationLocationVisible();
        int halve = r.length() / 4;
        if(enabled)
        	model.vlm.setAnnotationLocationVisible(new Location(r.start() + halve, r.end() + halve));

    }
    
    public static void perform(Model model){
    	AnnotationMoveRightAction action = new AnnotationMoveRightAction(model);
    	action.actionPerformed(null);
    }

}
